options.editor.select


add-valcljs

(add-val {:keys [id] :as opts})

editor-selectcljs

(editor-select {:keys [set-fn options]} current-val)

editor-select-multiplecljs

(editor-select-multiple {:keys [set-fn options]} current-val)

entry->optioncljs

(entry->option {:keys [id name]})

normalize-speccljs

(normalize-spec spec)

spec always has to be a vector of elements element type: map: spec of {:id :name} any other type. it is a list of ids which get converted to names with str.

spec always has to be a vector of elements
element type:
map: spec of {:id :name}
any other type. it is a list of ids which get converted to names with str.
raw docstring

spec->speccljs

(spec->spec specs)

val->mapcljs

(val->map idx val)

vals->speccljs

(vals->spec vals)

cljdoc builds & hosts documentation for Clojure/Script libraries