(add-val {:keys [id] :as opts})(editor-select {:keys [set-fn options]} current-val)(editor-select-multiple {:keys [set-fn options]} current-val)(entry->option {:keys [id name]})(normalize-spec spec)spec always has to be a vector of elements element type: map: spec of {:id :name} any other type. it is a list of ids which get converted to names with str.
spec always has to be a vector of elements
element type:
map: spec of {:id :name}
any other type. it is a list of ids which get converted to names with str.(spec->spec specs)(val->map idx val)(vals->spec vals)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |